@@ -1,39 +1,40 @@
-package App::Benchmark;
 use 5.008;
 use strict;
 use warnings;
+
+package App::Benchmark;
+our $VERSION = '1.100870';
+# ABSTRACT: Output your benchmarks as test diagnostics
+
 use Test::More;
 use Benchmark qw(cmpthese timethese :hireswallclock);
-use IO::Capture::Stdout;
-our $VERSION = '0.04';
-use base 'Exporter';
+use Capture::Tiny qw(capture);
+use Exporter qw(import);
 our @EXPORT = ('benchmark_diag');
 
 sub benchmark_diag {
     my ($iterations, $benchmark_hash) = @_;
-    my $capture = IO::Capture::Stdout->new;
-    $capture->start;
-    cmpthese(timethese($iterations, $benchmark_hash));
-    $capture->stop;
-    {
-        my $previous_default = select(STDOUT);
-        $|++;    # autoflush STDOUT
-        select(STDERR);
-        $|++;    # autoflush STDERR
-        select($previous_default);
-    }
-    chomp(my @lines = $capture->read);
-    warn "# $_\n" for @lines;
+    my $stdout = capture {
+        cmpthese(timethese($iterations, $benchmark_hash));
+    };
+    note $stdout;
     plan tests => 1;
     pass('benchmark');
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 App::Benchmark - Output your benchmarks as test diagnostics
 
+=head1 VERSION
+
+version 1.100870
+
 =head1 SYNOPSIS
 
     # This is t/benchmark.t:
@@ -56,9 +57,7 @@ Ricardo Signes came up with the idea.
 
 =head1 FUNCTIONS
 
-=over 4
-
-=item C<benchmark_diag>
+=head2 benchmark_diag
 
 Takes a number of iterations and a benchmark definition hash, just like
 C<timethese()> from the L<Benchmark> module. Runs the benchmarks and reports
@@ -67,35 +66,39 @@ Also, a dummy test is being generated to keep the testing framework happy.
 
 This function is exported automatically.
 
-=back
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=App-Benchmark>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/App-Benchmark/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/App-Benchmark/>.
 
-=head1 AUTHORS
+The development version lives at
+L<http://github.com/hanekomu/App-Benchmark/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+=head1 AUTHOR
+
+  Marcel Gruenauer <marcel@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2008 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
